emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Emacs-diffs] master 4594f89: Replace an obsolete function alias


From: Glenn Morris
Subject: [Emacs-diffs] master 4594f89: Replace an obsolete function alias
Date: Wed, 29 Apr 2015 06:40:56 +0000

branch: master
commit 4594f894e60a50e3b5449d762b44a6c69b1bcae6
Author: Glenn Morris <address@hidden>
Commit: Glenn Morris <address@hidden>

    Replace an obsolete function alias
    
    * lisp/isearch.el (isearch-yank-x-selection):
    * lisp/mouse-copy.el (mouse-drag-secondary-pasting)
    (mouse-drag-secondary-moving):
    * lisp/obsolete/mouse-sel.el (mouse-sel-get-selection-function):
    Replace obsolete alias x-get-selection with gui-get-selection.
---
 lisp/isearch.el            |    4 ++--
 lisp/mouse-copy.el         |    4 ++--
 lisp/obsolete/mouse-sel.el |    2 +-
 3 files changed, 5 insertions(+), 5 deletions(-)

diff --git a/lisp/mouse-copy.el b/lisp/mouse-copy.el
index 609713c..d3c3c80 100644
--- a/lisp/mouse-copy.el
+++ b/lisp/mouse-copy.el
@@ -177,7 +177,7 @@ put the point at one place, then click and drag over some 
other region."
            (mouse-copy-work-around-drag-bug start-event last-input-event))
        ;; Remember what we do so we can undo it, if necessary.
        (setq mouse-copy-last-paste-start (point))
-       (insert (x-get-selection 'SECONDARY))
+       (insert (gui-get-selection 'SECONDARY))
        (setq mouse-copy-last-paste-end (point)))
     (setq mouse-copy-last-paste-start nil)))
 
@@ -216,7 +216,7 @@ by address@hidden"
   (if (mouse-drag-secondary start-event)
       (progn
        (mouse-kill-preserving-secondary)
-       (insert (x-get-selection 'SECONDARY))))
+       (insert (gui-get-selection 'SECONDARY))))
 )
 
 (provide 'mouse-copy)
diff --git a/lisp/obsolete/mouse-sel.el b/lisp/obsolete/mouse-sel.el
index fcadedf..865a427 100644
--- a/lisp/obsolete/mouse-sel.el
+++ b/lisp/obsolete/mouse-sel.el
@@ -315,7 +315,7 @@ is `interprogram-cut-paste'.")
        (or (gui-selection-value)
            (bound-and-true-p x-last-selected-text-primary)
             gui--last-selected-text-primary)
-      (x-get-selection selection)))
+      (gui-get-selection selection)))
   "Function to call to get the selection.
 Called with one argument:
 



reply via email to

[Prev in Thread] Current Thread [Next in Thread]
diff --git a/lisp/isearch.el b/lisp/isearch.el
index 35fb060..c714ba0 100644
--- a/lisp/isearch.el
+++ b/lisp/isearch.el
@@ -1924,8 +1924,8 @@ If search string is empty, just beep."
 (defun isearch-yank-x-selection ()
   "Pull current X selection into search string."
   (interactive)
-  (isearch-yank-string (x-get-selection))
-  ;; If `x-get-selection' returned the text from the active region,
+  (isearch-yank-string (gui-get-selection))
+  ;; If `gui-get-selection' returned the text from the active region,
   ;; then it "used" the mark which we should hence deactivate.
   (when select-active-regions (deactivate-mark)))
 